@@ -20,7 +20,7 @@ __PACKAGE__->mk_accessors(qw(
     program socket proc
     package filename line codeline subroutine finished));
 
-our $VERSION = "0.53";
+our $VERSION = "0.54";
 
 # let's run the code under our debugger and connect to the server it
 # starts up
@@ -145,6 +145,7 @@ Devel::ebug - A simple, extensible Perl debugger
   $ebug->break_point(6, '$e == 4');
   $ebug->break_point("t/Calc.pm", 29);
   $ebug->break_point("t/Calc.pm", 29, '$i == 2');
+  $ebug->break_on_load("t/Calc.pm");
   my $actual_line = $ebug->break_point_subroutine("main::add");
   $ebug->break_point_delete(29);
   $ebug->break_point_delete("t/Calc.pm", 29);
@@ -262,6 +263,10 @@ this case a breakpoint will be set at the next breakable line, and the
 line number will be returned. If no such line exists, no breakpoint is
 set and the function returns C<undef>.
 
+=head2 break_on_load
+
+Set a breakpoint on file loading, the file name can be relative or absolute.
+
 =head2 break_point_delete
 
 The break_point_delete method deletes an existing break point. A break
@@ -520,7 +525,7 @@ Leon Brocard, C<< <acme@astray.com> >>
 =head1 COPYRIGHT
 
 Copyright (C) 2005-2008, Leon Brocard
-Copyright (C) 2011, Brock Wilcox
+Copyright (C) 2011-NOW, Brock Wilcox
 
 =head1 LICENSE
 
